local _, NS = ...
NS.AddonPath = "Interface\\Addons\\MovePadPlus\\"

------------ Texts and Localisation ---------------------------------------------
NS.Texts = {
	C2MTip = "Toggle\nClick-To-Move.",
	RotateTip = "Toggle\nRotate.",
	HoldRotateTip = "Hold\nRotate.",
	HideC2M = "Hide Click-2-Move",
	HideRotate = "Hide Rotate",
	HideTooltips = "Hide Tooltips",
	HideHoldRotate = "Hide Hold Rotate",
	SetKeybinds = "Set key binds",
	SwapRotates = "Swap Rotates",
}
local locale = GetLocale()
if locale == "ptBR" then
	NS.Texts = {
		C2MTip = "Ativar\\Desativar\nClicar-Para-Mover.",
		RotateTip = "Ativar\\Desativar\nRota\195\167\195\163o.",
		HoldRotateTip = "Travar\nRota\195\167\195\163o.",
		HideC2M = "Ocultar Clicar-Para-Mover",
		HideRotate = "Ocultar Rota\195\167\195\163o",
		HideTooltips = "Ocultar Dicas",
		HideHoldRotate = "Ocultar Travar Rota\195\167\195\163o",
		SetKeybinds = "Configurar Atalhos",
		SwapRotates = "Inverter Rota\195\167\195\163o",
	}
elseif locale == "frFR" then
--	NS.Texts = {
--		C2MTip = "French for Toggle\nClick-To-Move.",
--		RotateTip = "French for Toggle\nRotate.",
--	}
elseif locale == "deDE" then	
--	NS.Texts = {
--		C2MTip = "German for Toggle\nClick-To-Move.",
--		RotateTip = "German for Toggle\nRotate.",
--	}
end

------------ Local Functions ----------------------------------------------------

local function ButtonSetup(self)
	self:SetCheckedTexture("Interface\\Buttons\\CheckButtonGlow")
	local bm = self:GetCheckedTexture()
	bm:SetBlendMode("ADD")
	bm:SetTexCoord(0.1, 0.9, 0.1, 0.9)
	self.icon:SetTexCoord(0, 1, 0, 1)
end

local function GetState(arg1)
	local state
	local uicheck = arg1 or GetCVar("autointeract")
	if not uicheck or uicheck == "0" then
		state = false
	else
		state = true
	end
	return state
end

local function MovePadAnyChecked()
	if MovePadForward:GetChecked() or MovePadBackward:GetChecked() or MovePadStrafeLeft:GetChecked() or MovePadStrafeRight:GetChecked() then
		return true
	else
		return false
	end
end

local function	WorldMouseUpScript(self, button, up)
	local rotatebutton, script
	if NS.holdRotateButton.RotateOffOnUp then
		rotatebutton = NS.holdRotateButton
		script = NS.holdRotateButton:GetScript("OnMouseUp")
	elseif NS.rotateButton:GetChecked() then
		rotatebutton = NS.rotateButton
		script = NS.rotateButton:GetScript("OnClick")
	end
	if rotatebutton then
		rotatebutton:SetChecked(false)
		script(rotatebutton, button, up)
	end
end

local function SettoolTips()
	NS.c2mButton:SetScript("OnEnter", function(self)
			if MovePadPlus.HideTooltips then return end
			GameTooltip:SetOwner(self, "ANCHOR_BOTTOMLEFT", 0, self:GetHeight())
			GameTooltip:SetText(NS.Texts.C2MTip)
		end)
	NS.c2mButton:SetScript("OnLeave", function(self)
			if MovePadPlus.HideTooltips then return end
			GameTooltip:Hide()		
		end)
	NS.rotateButton:SetScript("OnEnter", function(self)
			if self.inTurn then
				self.inTurn = nil
			else
				if MovePadPlus.HideTooltips then return end
				GameTooltip:SetOwner(self, self.TTAnchor, 0, self:GetHeight())
				GameTooltip:SetText(NS.Texts.RotateTip)
			end
		end)
	NS.rotateButton:SetScript("OnLeave", function(self)
			if MovePadPlus.HideTooltips then return end
			GameTooltip:Hide()		
		end)
	NS.holdRotateButton:SetScript("OnEnter", function(self)
			if MovePadPlus.HideTooltips then return end
			GameTooltip:SetOwner(self, self.TTAnchor, 0, self:GetHeight())
			GameTooltip:SetText(NS.Texts.HoldRotateTip)
		end)
	NS.holdRotateButton:SetScript("OnLeave", function(self)
			if MovePadPlus.HideTooltips then return end
			GameTooltip:Hide()		
		end)
end

----------------------------------------------------------------------------------------- 
NS.c2mButton = CreateFrame("CheckButton", "MovePadPlus", UIParent, "UIPanelSquareButton")
ButtonSetup(NS.c2mButton)
NS.c2mButton:Hide()
NS.c2mButton:RegisterEvent("ADDON_LOADED")
NS.c2mButton:RegisterEvent("CVAR_UPDATE")
NS.c2mButton:SetScript("OnEvent", function(self, event, ...)
		if event == "ADDON_LOADED" then
			if ... ~= "Blizzard_MovePad" then return end
			self:UnregisterEvent("ADDON_LOADED")
			NS:InitialisEverything(self)
		end
	end)

----------------------------------------------------------------------------------------- 
function NS:SetShown(data, index, pressed)
	local button
	local hide = data[index]
	if index == "HideClick2Move" then
		button = NS.c2mButton	
	elseif index == "HideRotate" then
		button = NS.rotateButton
	elseif index == "HideHoldRotate" then
		button = NS.holdRotateButton
	end	
	if not button then return end
	if hide then
		button:Hide()
		local click = button:GetScript("OnClick") or button:GetScript("OnMouseUp")
		button:SetChecked(false)
		click(button, pressed)
	else
		button:Show()
	end
end

function NS:AnchorRotateButtons()
	NS.rotateButton:ClearAllPoints()
	NS.holdRotateButton:ClearAllPoints()
	if MovePadPlus.SwapRotates then
		NS.rotateButton:SetPoint("LEFT", MovePadJump, "RIGHT")
		NS.holdRotateButton:SetPoint("RIGHT", MovePadJump, "LEFT")
		NS.rotateButton.TTAnchor = "ANCHOR_BOTTOMRIGHT"
		NS.holdRotateButton.TTAnchor = "ANCHOR_BOTTOMLEFT"
	else
		NS.rotateButton:SetPoint("RIGHT", MovePadJump, "LEFT")
		NS.holdRotateButton:SetPoint("LEFT", MovePadJump, "RIGHT")
		NS.rotateButton.TTAnchor = "ANCHOR_BOTTOMLEFT"
		NS.holdRotateButton.TTAnchor = "ANCHOR_BOTTOMRIGHT"
	end
end

function NS:InitialisEverything(c2mBtn)
	if not MovePadPlus then MovePadPlus = {} end
	if not MovePadPlus.Buttons then
		MovePadPlus.HideTooltips = false
		MovePadPlus.Buttons = {
					HideClick2Move=false,
					HideRotate=false,
				}
	end
	if not MovePadPlus.Buttons.HideHoldRotate then
		MovePadPlus.Buttons.HideHoldRotate = false
	end
	MovePadFrame:HookScript("OnShow", function(self)
			NS:SetShown(MovePadPlus.Buttons, "HideClick2Move")
			NS:SetShown(MovePadPlus.Buttons, "HideRotate")
			NS:SetShown(MovePadPlus.Buttons, "HideHoldRotate")
			if NS.configFrame then
				NS.configFrame:Hide()
				NS.configButton:SetChecked(false)
			end
		end)
	WorldFrame:HookScript("OnMouseUp", WorldMouseUpScript)
	c2mBtn.icon:SetSize(21, 21)
	c2mBtn.icon:SetTexture(NS.AddonPath .. "GoldBoot")
	c2mBtn:RegisterForClicks("AnyUp")
	c2mBtn:SetParent(MovePadFrame)
	c2mBtn:SetSize(38, 38)
	c2mBtn:SetPoint("RIGHT", MovePadBackward, "LEFT")
	c2mBtn:SetChecked(GetState())
	c2mBtn:SetScript("OnEvent", function(self, event, ...)
			if ... ~= "CLICK_TO_MOVE" then return end
			local _, uicheck = ...
			self:SetChecked(GetState(uicheck))
		end)
	c2mBtn:SetScript("OnClick", function(self, button, up)
			local uicheck
			if self:GetChecked() then
				uicheck = "1"
			else
				uicheck = "0"
			end
			SetCVar("autointeract", uicheck)
			InterfaceOptionsMousePanelClickToMove:SetChecked(uicheck)
			PlaySound("igMainMenuOptionCheckBoxOn")
		end)
	NS:SetShown(MovePadPlus.Buttons, "HideClick2Move")

	NS.rotateButton = CreateFrame("CheckButton", "MovePadPlusRotate", MovePadFrame, "UIPanelSquareButton")
	NS:SetShown(MovePadPlus.Buttons, "HideRotate")
	ButtonSetup(NS.rotateButton)
	NS.rotateButton:RegisterEvent("PLAYER_STARTED_MOVING")
	NS.rotateButton:SetSize(c2mBtn:GetSize())
	NS.rotateButton:RegisterForClicks("AnyUp")
	NS.rotateButton.icon:SetSize(20, 20)
	NS.rotateButton.icon:SetTexture(NS.AddonPath.. "Rotate")
	NS.rotateButton.icon:SetVertexColor(.75, .75, 0)
	NS.rotateButton:SetScript("OnEvent", function(self, event, ...)
			if self:GetChecked() then -- PLAYER_STARTED_MOVING using keyboard or gamepad
				self:SetChecked(false)
				MouselookStop()
			end
		end)
	NS.rotateButton:SetScript("OnClick", function(self, button, up)
			if not self:GetChecked() then
				MouselookStop()
			else
				if not MovePadPlus.NotoolTip then self.inTurn = true end
				MouselookStart()
			end
		end)

	NS.holdRotateButton = CreateFrame("CheckButton", "MovePadPlusHoldRotate", MovePadFrame, "UIPanelSquareButton")
	NS:SetShown(MovePadPlus.Buttons, "HideHoldRotate")
	ButtonSetup(NS.holdRotateButton)
	NS.holdRotateButton:SetSize(c2mBtn:GetSize())
	NS.holdRotateButton:RegisterForClicks("AnyUp")
	NS.holdRotateButton:RegisterForClicks("AnyDown")
	NS.holdRotateButton.icon:SetSize(20, 20)
	NS.holdRotateButton.NTexture = NS.holdRotateButton:GetNormalTexture()
	NS.holdRotateButton.HTexture = NS.holdRotateButton:GetHighlightTexture()
	NS.holdRotateButton.icon:SetTexture(NS.AddonPath.. "HoldRotate")
	NS.holdRotateButton.icon:SetVertexColor(.75, .75, 0)
	NS.holdRotateButton:SetScript("OnMouseDown", function(self, button, up)
			self:SetNormalTexture(self.HTexture)
			MouselookStart()
			self.RotateOffOnUp = true
		end)
	NS.holdRotateButton:SetScript("OnMouseUp", function(self, button, up)
			if not self.RotateOffOnUp then return end
			self:SetNormalTexture(self.NTexture)
			self.RotateOffOnUp = nil
			MouselookStop()
		end)

	NS.configButton = CreateFrame("CheckButton", "MovePadPlusConfig", MovePadFrame, "UIPanelSquareButton")
	ButtonSetup(NS.configButton)
	NS.configButton:SetAlpha(.3)
	NS.configButton.icon:SetTexture(NS.AddonPath.. "Config")
	NS.configButton:SetSize(15, 15)
	NS.configButton.icon:SetSize(16, 16)
	NS.configButton:SetPoint("BOTTOMLEFT", MovePadFrame, "BOTTOMRIGHT")
	NS.configButton:RegisterForClicks("AnyUp")
	NS.configButton:SetScript("OnEnter", function(self)
			self:SetAlpha(1)
		end)
	NS.configButton:SetScript("OnLeave", function(self)
			self:SetAlpha(.3)
		end)
	NS.configButton:SetScript("OnClick", function(self, button)
			if not NS.configFrame then
				NS:CreateConfig()
			end
			if self:GetChecked() then
				NS.configFrame:Show()
			else
				NS.configFrame:Hide()
			end
		end)
	NS:AnchorRotateButtons()
	SettoolTips()
end
